==> react-molecule-progress-steps-1.3.0.tgz: package/lib/index.js <==
import React, { useRef } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import MoleculeProgressStep, { STATUSES } from './components/MoleculeProgressStep';
var BASE_CLASS = "sui-MoleculeProgressSteps";
var CLASS_STEPS = BASE_CLASS + "-path";
var CLASS_CONTENT = BASE_CLASS + "-content";
var CLASS_COMPRESSED_INFO = BASE_CLASS + "-compressedInfo";
var CLASS_VERTICAL = BASE_CLASS + "--vertical";
var CLASS_COMPRESSED = BASE_CLASS + "--compressed";

var MoleculeProgressSteps = function MoleculeProgressSteps(_ref) {
  var _cx;

  var vertical = _ref.vertical,
      children = _ref.children,
      iconStepDone = _ref.iconStepDone,
      compressed = _ref.compressed;
  var activeStepContent = useRef();
  var className = cx(BASE_CLASS, (_cx = {}, _cx[CLASS_VERTICAL] = vertical, _cx[CLASS_COMPRESSED] = compressed, _cx));

  var getCompressedInfoSteps = function getCompressedInfoSteps() {
    var childrenNodes = React.Children.toArray(children);
    var totalSteps = childrenNodes.length;

    var _childrenNodes$reduce = childrenNodes.reduce(function (acc, child, index) {
      var status = child.props.status;
      if (status === STATUSES.ACTIVE) acc = [child.props.label, index + 1];
      return acc;
    }, []),
        activeLabel = _childrenNodes$reduce[0],
        numActiveStep = _childrenNodes$reduce[1];

    var stepPositionInfo = numActiveStep + "/" + totalSteps;
    return stepPositionInfo + ": " + activeLabel;
  };

  var extendedChildren = React.Children.toArray(children).filter(Boolean).map(function (child, index, children) {
    var _child$props = child.props,
        iconChild = _child$props.icon,
        iconActive = _child$props.iconActive,
        status = _child$props.status,
        childrenChild = _child$props.children;
    var totalChildren = children.length;
    var numStep = index + 1;
    var lastStep = index >= totalChildren - 1;
    var isVisited = status === STATUSES.VISITED;
    var isActive = status === STATUSES.ACTIVE;
    var icon = iconChild;
    if (isVisited) icon = iconStepDone;

    if (isActive) {
      icon = iconActive || iconChild;
      activeStepContent.current = childrenChild;
    }

    return React.cloneElement(child, {
      numStep: numStep,
      lastStep: lastStep,
      icon: icon,
      compressed: compressed
    });
  });
  return /*#__PURE__*/React.createElement("div", {
    className: className
  }, compressed && /*#__PURE__*/React.createElement("p", {
    className: CLASS_COMPRESSED_INFO
  }, getCompressedInfoSteps()), /*#__PURE__*/React.createElement("div", {
    className: CLASS_STEPS
  }, extendedChildren), /*#__PURE__*/React.createElement("div", {
    className: CLASS_CONTENT
  }, activeStepContent.current));
};

MoleculeProgressSteps.displayName = 'MoleculeProgressSteps';
export default MoleculeProgressSteps;
export { MoleculeProgressStep, STATUSES };

==> react-molecule-progress-steps-1.4.0.tgz: package/lib/index.js <==
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { Children, cloneElement, useRef } from 'react';
import cx from 'classnames';
import MoleculeProgressStep, { STATUSES } from './components/MoleculeProgressStep';
var BASE_CLASS = "sui-MoleculeProgressSteps";
var CLASS_STEPS = BASE_CLASS + "-path";
var CLASS_CONTENT = BASE_CLASS + "-content";
var CLASS_COMPRESSED_INFO = BASE_CLASS + "-compressedInfo";
var CLASS_VERTICAL = BASE_CLASS + "--vertical";
var CLASS_COMPRESSED = BASE_CLASS + "--compressed";

var MoleculeProgressSteps = function MoleculeProgressSteps(_ref) {
  var _cx;

  var vertical = _ref.vertical,
      children = _ref.children,
      iconStepDone = _ref.iconStepDone,
      compressed = _ref.compressed;
  var activeStepContent = useRef();
  var className = cx(BASE_CLASS, (_cx = {}, _cx[CLASS_VERTICAL] = vertical, _cx[CLASS_COMPRESSED] = compressed, _cx));

  var getCompressedInfoSteps = function getCompressedInfoSteps() {
    var childrenNodes = Children.toArray(children);
    var totalSteps = childrenNodes.length;

    var _childrenNodes$reduce = childrenNodes.reduce(function (acc, child, index) {
      var status = child.props.status;
      if (status === STATUSES.ACTIVE) acc = [child.props.label, index + 1];
      return acc;
    }, []),
        activeLabel = _childrenNodes$reduce[0],
        numActiveStep = _childrenNodes$reduce[1];

    var stepPositionInfo = numActiveStep + "/" + totalSteps;
    return stepPositionInfo + ": " + activeLabel;
  };

  var extendedChildren = Children.toArray(children).filter(Boolean).map(function (child, index, children) {
    var _child$props = child.props,
        iconChild = _child$props.icon,
        iconActive = _child$props.iconActive,
        status = _child$props.status,
        childrenChild = _child$props.children;
    var totalChildren = children.length;
    var numStep = index + 1;
    var lastStep = index >= totalChildren - 1;
    var isVisited = status === STATUSES.VISITED;
    var isActive = status === STATUSES.ACTIVE;
    var icon = iconChild;
    if (isVisited) icon = iconStepDone;

    if (isActive) {
      icon = iconActive || iconChild;
      activeStepContent.current = childrenChild;
    }

    return /*#__PURE__*/cloneElement(child, {
      numStep: numStep,
      lastStep: lastStep,
      icon: icon,
      compressed: compressed
    });
  });
  return /*#__PURE__*/_jsxs("div", {
    className: className,
    children: [compressed && /*#__PURE__*/_jsx("p", {
      className: CLASS_COMPRESSED_INFO,
      children: getCompressedInfoSteps()
    }), /*#__PURE__*/_jsx("div", {
      className: CLASS_STEPS,
      children: extendedChildren
    }), /*#__PURE__*/_jsx("div", {
      className: CLASS_CONTENT,
      children: activeStepContent.current
    })]
  });
};

MoleculeProgressSteps.displayName = 'MoleculeProgressSteps';
export default MoleculeProgressSteps;
export { MoleculeProgressStep, STATUSES };
